@@ -5,25 +5,26 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.82';
+$VERSION = '0.83';
 
 sub _init_compile_opts {
    my $self = shift;
    my $opt  = shift || {};
 
-   fatal('tts.base.compiler._compile.opt')   if not ishref($opt  );
+   fatal('tts.base.compiler._compile.opt') if ! ishref( $opt );
 
    # set defaults
    $opt->{id}       ||= EMPTY_STRING; # id is AUTO
-   $opt->{map_keys} ||= 0;  # use normal behavior
-   $opt->{chkmt}    ||= 0;  # check mtime of file template?
-   $opt->{_sub_inc} ||= 0;  # are we called from a dynamic include op?
+   $opt->{map_keys} ||= 0;            # use normal behavior
+   $opt->{chkmt}    ||= 0;            # check mtime of file template?
+   $opt->{_sub_inc} ||= 0;            # are we called from a dynamic include op?
    $opt->{_filter}  ||= EMPTY_STRING; # any filters?
 
    # first element is the shared names. if it's not defined, then there
    # are no shared variables from top level
-   delete $opt->{_share}
-      if isaref($opt->{_share}) && ! defined $opt->{_share}[0];
+   if ( isaref($opt->{_share}) && ! defined $opt->{_share}[0] ) {
+      delete $opt->{_share};
+   }
 
    $opt->{as_is} = $opt->{_sub_inc} && $opt->{_sub_inc} == T_STATIC;
 
@@ -205,8 +206,8 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.82> of C<Text::Template::Simple::Base::Compiler>
-released on C<30 May 2010>.
+This document describes version C<0.83> of C<Text::Template::Simple::Base::Compiler>
+released on C<9 February 2011>.
 
 Private module.
 
@@ -216,12 +217,12 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2010 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2011 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.1 or, 
+it under the same terms as Perl itself, either Perl version 5.12.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
