@@ -5,7 +5,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.82';
+$VERSION = '0.83';
 
 sub _examine {
    my $self   = shift;
@@ -41,8 +41,9 @@ sub _examine {
 
 sub _examine_glob {
    my($self, $thing) = @_;
-   fatal( 'tts.base.examine.notglob' => ref $thing ) if ref $thing ne 'GLOB';
-   fatal( 'tts.base.examine.notfh' ) if ! fileno $thing;
+   my $type = ref $thing;
+   fatal( 'tts.base.examine.notglob' => $type ) if $type ne 'GLOB';
+   fatal( 'tts.base.examine.notfh'            ) if ! fileno $thing;
    return $self->io->slurp( $thing );
 }
 
@@ -78,8 +79,8 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.82> of C<Text::Template::Simple::Base::Examine>
-released on C<30 May 2010>.
+This document describes version C<0.83> of C<Text::Template::Simple::Base::Examine>
+released on C<9 February 2011>.
 
 Private module.
 
@@ -89,12 +90,12 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2010 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2011 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.1 or, 
+it under the same terms as Perl itself, either Perl version 5.12.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
